################
Experiment class
################

The Experiment class is intended for use in the Jupyter notebook environment.

.. automodule:: pymeasure.experiment.experiment
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: 